# Table of Contents

- [calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields](<./calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Calculating Scores from Numeric Fields and Updating Custom Fact Sheet Fields](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields.md>)
  - [Overview](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Overview.md>)
  - [Prerequisites](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Prerequisites.md>)
  - [Step 1: Create Custom Fact Sheet Fields](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Step-1-Create-Custom-Fact-Sheet-Fields.md>)
  - [Step 2: Map Risk Scores to Risk Tiers](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Step-2-Map-Risk-Scores-to-Risk-Tiers.md>)
  - [Step 3: Configure a Connector](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Step-3-Configure-a-Connector.md>)
  - [Summary](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Summary.md>)
  - [Was this page helpful?](<./Calculating-Scores-from-Numeric-Fields-and-Updating-Custom-Fact-Sheet-Fields/Was-this-page-helpful.md>)
